# PyRW

Python Read/Write Everything Wrapper. This module attempts to wrap some of RW-Everything's functionality in a way that makes it easy to access some hardware within a Python script. 

# Prerequisites

As of now, RWE is included with this package.

# RW-Everything

Read/Write Everything is an amazing tool that can be used to access almost all computer hardware. It is really cool. It is the basis for this Python package.

For more information and to download directly check out http://rweverything.com/.
If it works really well for you, consider making a donation to the author as well.
